pub struct DsdChunk { /* private fields */ }Expand description
The DSD chunk is the first chunk of a DSF file.
It contains the DSF file size and the offset of the ID3v2 tag if
one exists.
Implementations